@@ -1,6 +1,10 @@
 package Alien::LibXML;
+use strict;
+use warnings;
 use parent 'Alien::Base';
-our $VERSION = '0.000_02';
+our $VERSION = '0.001';
+
+__END__
 
 =pod
 
@@ -8,12 +12,20 @@ our $VERSION = '0.000_02';
 
 =head1 NAME
 
-Alien::LibXML - just coz
+Alien::LibXML - install the C libxml2 library on your system
+
+=head1 SYNOPSIS
+
+   use 5.010;
+   use strict;
+   use Alien::LibXML;
+   
+   my $alien = Alien::LibXML->new;
+   say $alien->libs;
+   say $alien->cflags;
 
 =head1 DESCRIPTION
 
-This is a very early test version of Alien::LibXML.
-
 Hopefully at some point, L<XML::LibXML>'s installation scripts might use
 Alien::LibXML to locate or install the C libxml2 library.
 
@@ -23,7 +35,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT, LICENCE AND DISCLAIMER OF WARRANTIES
 
-Copyright (c) 2012 Toby Inkster.
+Copyright (c) 2012-2013 Toby Inkster.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
